bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.broadcasting_multiplier
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.broadcasting_multiplier